import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["conditionalSubmitFlag", "buttons"];
import React from 'react';
import PropTypes from 'prop-types';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import selectNext from '@data-driven-forms/common/wizard/select-next';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import Button from "semantic-ui-react/dist/es/elements/Button/Button.js";
var useStyles = createUseStyles({
  root: {
    display: 'flex',
    justifyContent: 'space-between'
  }
});

var NextButton = function NextButton(_ref) {
  var nextStep = _ref.nextStep,
      valid = _ref.valid,
      handleNext = _ref.handleNext,
      nextLabel = _ref.nextLabel,
      getState = _ref.getState,
      handleSubmit = _ref.handleSubmit,
      submitLabel = _ref.submitLabel,
      conditionalSubmitFlag = _ref.conditionalSubmitFlag;
  var nextResult = nextStep ? selectNext(nextStep, getState) : nextStep;
  var progressNext = nextResult !== conditionalSubmitFlag && nextStep;
  return /*#__PURE__*/React.createElement(Button, {
    icon: progressNext ? 'right arrow' : undefined,
    color: "blue",
    labelPosition: progressNext ? 'right' : undefined,
    content: progressNext ? nextLabel : submitLabel,
    disabled: !valid || getState().validating || getState().submitting,
    onClick: function onClick() {
      return progressNext ? handleNext(nextResult) : handleSubmit();
    },
    type: "button"
  });
};

NextButton.propTypes = {
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.object]),
  handleSubmit: PropTypes.func.isRequired,
  submitLabel: PropTypes.node.isRequired,
  valid: PropTypes.bool,
  handleNext: PropTypes.func.isRequired,
  nextLabel: PropTypes.node.isRequired,
  getState: PropTypes.func.isRequired,
  conditionalSubmitFlag: PropTypes.string.isRequired
};

var WizardStepButtons = function WizardStepButtons(_ref2) {
  var conditionalSubmitFlag = _ref2.conditionalSubmitFlag,
      Buttons = _ref2.buttons,
      props = _objectWithoutProperties(_ref2, _excluded);

  var classes = useStyles();

  if (Buttons) {
    return /*#__PURE__*/React.createElement(Buttons, props);
  }

  var disableBack = props.disableBack,
      handlePrev = props.handlePrev,
      nextStep = props.nextStep,
      handleNext = props.handleNext,
      _props$buttonLabels = props.buttonLabels,
      cancel = _props$buttonLabels.cancel,
      submit = _props$buttonLabels.submit,
      back = _props$buttonLabels.back,
      next = _props$buttonLabels.next,
      formOptions = props.formOptions;
  return /*#__PURE__*/React.createElement(FormSpy, {
    subscription: {
      values: true,
      valid: true,
      validating: true,
      submitting: true
    }
  }, function () {
    return /*#__PURE__*/React.createElement("div", {
      className: classes.root
    }, /*#__PURE__*/React.createElement(Button, {
      type: "button",
      onClick: formOptions.onCancel
    }, cancel), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Button, {
      icon: "left arrow",
      labelPosition: "left",
      content: back,
      type: "button",
      disabled: disableBack,
      onClick: handlePrev
    }), /*#__PURE__*/React.createElement(NextButton, _extends({}, formOptions, {
      conditionalSubmitFlag: conditionalSubmitFlag,
      handleNext: handleNext,
      nextStep: nextStep,
      nextLabel: next,
      submitLabel: submit
    }))));
  });
};

WizardStepButtons.propTypes = {
  disableBack: PropTypes.bool,
  handlePrev: PropTypes.func.isRequired,
  handleNext: PropTypes.func.isRequired,
  conditionalSubmitFlag: PropTypes.string.isRequired,
  nextStep: PropTypes.oneOfType([PropTypes.string, PropTypes.shape({
    when: PropTypes.string.isRequired,
    stepMapper: PropTypes.object.isRequired
  }), PropTypes.func]),
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node.isRequired,
    cancel: PropTypes.node.isRequired,
    back: PropTypes.node.isRequired,
    next: PropTypes.node.isRequired
  }).isRequired,
  buttons: PropTypes.oneOfType([PropTypes.node, PropTypes.func]),
  formOptions: PropTypes.shape({
    getState: PropTypes.func.isRequired,
    onCancel: PropTypes.func.isRequired
  })
};
export default WizardStepButtons;